@@ -15,22 +15,22 @@ addPicture <- function(file, sheet, scale=1, startRow=1, startColumn=1)
   .jcall(iStream, "V", "close")
 
   wb <- .jcall(sheet,
-    "Lorg/apache/poi/xssf/usermodel/XSSFWorkbook;", "getWorkbook")
+    "Lorg/apache/poi/ss/usermodel/Workbook;", "getWorkbook")
   
   extId <- .jfield(wb, "I", pic_ext) 
   picId <- .jcall(wb, "I", "addPicture", bytes, as.integer(extId))
   
   drawing <- .jcall(sheet,
-    "Lorg/apache/poi/xssf/usermodel/XSSFDrawing;", "createDrawingPatriarch")   
+    "Lorg/apache/poi/ss/usermodel/Drawing;", "createDrawingPatriarch")   
   factory <- .jcall(wb,
-    "Lorg/apache/poi/xssf/usermodel/XSSFCreationHelper;", "getCreationHelper")
+    "Lorg/apache/poi/ss/usermodel/CreationHelper;", "getCreationHelper")
   anchor <- .jcall(factory,
     "Lorg/apache/poi/ss/usermodel/ClientAnchor;", "createClientAnchor")
   .jcall(anchor, "V", "setCol1", as.integer(startColumn-1))
   .jcall(anchor, "V", "setRow1", as.integer(startRow-1))
 
   # create the picture
-  pict <- .jcall(drawing, "Lorg/apache/poi/xssf/usermodel/XSSFPicture;",
+  pict <- .jcall(drawing, "Lorg/apache/poi/ss/usermodel/Picture;",
     "createPicture", anchor, as.integer(picId))
   .jcall(pict, "V", "resize", scale)
 
