@@ -1,8 +1,9 @@
 # One sheet extraction.  Similar to read.csv. 
 #
 #
-read.xlsx <- function(file, sheetIndex, sheetName=NULL, rowIndex=NULL,
-  colIndex=NULL, as.data.frame=TRUE, header=TRUE, colClasses=NA,
+read.xlsx <- function(file, sheetIndex, sheetName=NULL,
+  rowIndex=NULL, startRow=NULL, endRow=NULL, colIndex=NULL,
+  as.data.frame=TRUE, header=TRUE, colClasses=NA,
   keepFormulas=FALSE, encoding="unknown", ...)
 {
   if (is.null(sheetName) & missing(sheetIndex))
@@ -10,25 +11,36 @@ read.xlsx <- function(file, sheetIndex, sheetName=NULL, rowIndex=NULL,
 
   wb <- loadWorkbook(file)
   sheets <- getSheets(wb)
-
-  if (is.null(sheetName)){
-    sheet <- sheets[[sheetIndex]]
+  sheet  <- if (is.null(sheetName)) {
+    sheets[[sheetIndex]]
   } else {
-    sheet <- sheets[[sheetName]]
+    sheets[[sheetName]]
   }
+  
+  if (is.null(sheet))
+    stop("Cannot find the sheet you requested in the file!")
 
+  rowIndex <- if (is.null(rowIndex)) {
+    if (is.null(startRow))
+      startRow <- .jcall(sheet, "I", "getFirstRowNum") + 1
+    if (is.null(endRow)) 
+      endRow <- .jcall(sheet, "I", "getLastRowNum") + 1
+    startRow:endRow
+  }
+  
   rows  <- getRows(sheet, rowIndex)  
   cells <- getCells(rows, colIndex)
   res <- lapply(cells, getCellValue, keepFormulas=keepFormulas,
                 encoding=encoding)
-  
-  if (as.data.frame){
+
+  if (as.data.frame) {
     # need to use the index from the names because of empty cells
     ind <- lapply(strsplit(names(res), "\\."), as.numeric) 
     namesIndM <- do.call(rbind, ind)
     
     row.names <- sort(as.numeric(unique(namesIndM[,1])))
     col.names <- paste("V", sort(unique(namesIndM[,2])), sep="")  
+    col.names <- sort(unique(namesIndM[,2]))
     cols <- length(col.names)
 
     VV <- matrix(list(NA), nrow=length(row.names), ncol=cols,
@@ -47,12 +59,12 @@ read.xlsx <- function(file, sheetIndex, sheetName=NULL, rowIndex=NULL,
     for (ic in seq_len(cols)) {
       aux   <- unlist(VV[,ic], use.names=FALSE)
       nonNA <- which(!is.na(aux)) 
-      if (length(nonNA)>0){  # not a NA column in the middle of data
+      if (length(nonNA)>0) {  # not a NA column in the middle of data
         ind <- min(nonNA)
-        if (class(aux[ind])=="numeric"){
+        if (class(aux[ind])=="numeric") {
           # test first not NA cell if it's a date/datetime
           dateUtil <- .jnew("org/apache/poi/ss/usermodel/DateUtil")
-          cell <- cells[[paste(ind+header, ".", ic, sep="")]]
+          cell <- cells[[paste(row.names[ind + header], ".", col.names[ic], sep = "")]]
           isDatetime <- dateUtil$isCellDateFormatted(cell)
           if (isDatetime){
             if (identical(aux, round(aux))){ # you have dates
